# -*- coding: utf-8 -*-

import zeep

# Webová služba pro práci s uživateli (zakládání, přidělování rolí, přihlašování apod.)
class UserManagement(object):
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/UserManagement.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/UserManagement.asmx?wsdl')

    # Načíst seznam rolí uživatele v jednotce
    def UserRoleAllUserUnit(self, ID_Login, ID_User, ID_Unit):
        return self._client.service.UserRoleAllUserUnit({"ID_Login": ID_Login, "ID_User": ID_User, "ID_Unit": ID_Unit})

    # K danému datu vrátí nejbližší možný pracovní den
    def HolidayDetailNotHoliday(self, ID_Login, Date):
        return self._client.service.HolidayDetailNotHoliday({"ID_Login": ID_Login, "Date": Date})

    # Naèíst informace o pøihlášení pro 2F
    def LoginDetailTwoFactor(self, ID_Login):
        return self._client.service.LoginDetailTwoFactor({"ID_Login": ID_Login})

    # Naèíst informace o pøihlášení
    def LoginDetail(self, ID_Login):
        return self._client.service.LoginDetail({"ID_Login": ID_Login})

    # Ověření uživatele přes dvoufázové přihlášení
    def LoginUpdateTwoFactor(self, ID, ID_Application, SaveDevice, Code=None, ID_TwoFactorType=None, DisplayName=None):
        return self._client.service.LoginUpdateTwoFactor({"ID": ID, "ID_Application": ID_Application, "SaveDevice": SaveDevice, "Code": Code, "ID_TwoFactorType": ID_TwoFactorType, "DisplayName": DisplayName})

    # Automaticky nastavit vhodnou roli
    def LoginUpdateRoleAuto(self, ID_Login, ID, ID_Group, ID_Table=None, ID_Action=None, RequiredPermissions=None):
        return self._client.service.LoginUpdateRoleAuto({"ID_Login": ID_Login, "ID": ID, "ID_Group": ID_Group, "ID_Table": ID_Table, "ID_Action": ID_Action, "RequiredPermissions": RequiredPermissions})

    # Načíst seznam pluginů
    def PluginAll(self, ID_Login, ID=None, DisplayName=None, InstanceKey=None):
        return self._client.service.PluginAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName, "InstanceKey": InstanceKey})

    # Načíst detail pluginu
    def PluginDetail(self, ID_Login, ID=None):
        return self._client.service.PluginDetail({"ID_Login": ID_Login, "ID": ID})

    # Upravit plugin
    def PluginUpdate(self, ID_Login, IsEnabled, ID=None, DisplayName=None, Description=None):
        return self._client.service.PluginUpdate({"ID_Login": ID_Login, "IsEnabled": IsEnabled, "ID": ID, "DisplayName": DisplayName, "Description": Description})

    # Upravit poøadí tabulky
    def TableSetOrder(self, ID_Login, TableSetOrderType, ID, OrderInc, ID_Table=None, ID_ParentTable=None, FilterValues=None):
        return self._client.service.TableSetOrder({"ID_Login": ID_Login, "TableSetOrderType": TableSetOrderType, "ID": ID, "OrderInc": OrderInc, "ID_Table": ID_Table, "ID_ParentTable": ID_ParentTable, "FilterValues": FilterValues})

    # Načíst seznam skupin nastavení
    def SettingsGroupAll(self, ID_Login, ID, DisplayName=None):
        return self._client.service.SettingsGroupAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Informace o dočasném souboru
    def TempFileDetail(self, ID_Login, ID, ID_Application):
        return self._client.service.TempFileDetail({"ID_Login": ID_Login, "ID": ID, "ID_Application": ID_Application})

    # Vložení dočasného souboru
    def TempFileInsertDocument(self, Size, ImageWidth, ImageHeigth, ID_Login, ID_Application, ContentType=None, Extension=None, HashMD5=None, Content=None, DisplayName=None, Filename=None):
        return self._client.service.TempFileInsertDocument({"Size": Size, "ImageWidth": ImageWidth, "ImageHeigth": ImageHeigth, "ID_Login": ID_Login, "ID_Application": ID_Application, "ContentType": ContentType, "Extension": Extension, "HashMD5": HashMD5, "Content": Content, "DisplayName": DisplayName, "Filename": Filename})

    # No documentation
    def TempFileMaintrance(self, ID_Login):
        return self._client.service.TempFileMaintrance({"ID_Login": ID_Login})

    # No documentation
    def TableMaintrance(self, ID_Login, Databases=None):
        return self._client.service.TableMaintrance({"ID_Login": ID_Login, "Databases": Databases})

    # No documentation
    def TableRebuild(self, ID_Login, OnlyFast):
        return self._client.service.TableRebuild({"ID_Login": ID_Login, "OnlyFast": OnlyFast})

    # Stáhnout dočasný soubor
    def TempFileDownload(self, ID_Login, ID, ID_Application):
        return self._client.service.TempFileDownload({"ID_Login": ID_Login, "ID": ID, "ID_Application": ID_Application})

    # Vložení dočasného souboru
    def TempFileInsert(self, Size, ID_Login, ID_Application, Extension=None, Content=None, Hash=None, Filename=None):
        return self._client.service.TempFileInsert({"Size": Size, "ID_Login": ID_Login, "ID_Application": ID_Application, "Extension": Extension, "Content": Content, "Hash": Hash, "Filename": Filename})

    # Načíst seznam vhodných rolí podle funkcí
    def RoleAllFunction(self, ID_Login, ID_User):
        return self._client.service.RoleAllFunction({"ID_Login": ID_Login, "ID_User": ID_User})

    # Naèíst seznam pøihlášení
    def LoginAll(self, ID_ApplicationNotCurrent, ID_Login, Count, NotEqual, ID_Application, Success):
        return self._client.service.LoginAll({"ID_ApplicationNotCurrent": ID_ApplicationNotCurrent, "ID_Login": ID_Login, "Count": Count, "NotEqual": NotEqual, "ID_Application": ID_Application, "Success": Success})

    # Zda se nemá z IP odhlašovat
    def PersistentIPDetailIsPersitent(self, ID_Login, IP=None):
        return self._client.service.PersistentIPDetailIsPersitent({"ID_Login": ID_Login, "IP": IP})

    # Naèíst seznam Nastavení
    def SettingsAllPublic(self, ID_Login, ID_Application):
        return self._client.service.SettingsAllPublic({"ID_Login": ID_Login, "ID_Application": ID_Application})

    # Přidá/odebere přihlášeného uživatele do skupiny aplikace
    def GroupMemberApplication(self, ID_Login, Grant):
        return self._client.service.GroupMemberApplication({"ID_Login": ID_Login, "Grant": Grant})

    # Naèíst detail instance skautISu
    def InstanceDetail(self, ID_Login, ID_Application):
        return self._client.service.InstanceDetail({"ID_Login": ID_Login, "ID_Application": ID_Application})

    # Naèíst seznam Nastavení
    def SettingsAll(self, ID_Login, ID_SettingsGroup, DisplayName=None):
        return self._client.service.SettingsAll({"ID_Login": ID_Login, "ID_SettingsGroup": ID_SettingsGroup, "DisplayName": DisplayName})

    # Naèíst detail Nastavení
    def SettingsDetail(self, ID_Login, ID_Application, ID=None):
        return self._client.service.SettingsDetail({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID": ID})

    # Upravit 
    def SettingsUpdate(self, ID_Login, ID=None, DisplayName=None, Value=None, Note=None):
        return self._client.service.SettingsUpdate({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName, "Value": Value, "Note": Note})

    # No documentation
    def TableArchive(self, ID_Login):
        return self._client.service.TableArchive({"ID_Login": ID_Login})

    # Načíst seznam typů dvoufaktorového ověření
    def TwoFactorTypeAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.TwoFactorTypeAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Založit aktivaci účtu
    def UserActivationInsert(self, ID_Login, ID, Birthday, ValidTo, Activated, ID_Application, Code=None, UserName=None, Password=None, NickName=None, FirstName=None, LastName=None, ID_Sex=None, Email=None, IP=None, FirstNameParent=None, LastNameParent=None, EmailParent=None):
        return self._client.service.UserActivationInsert({"ID_Login": ID_Login, "ID": ID, "Birthday": Birthday, "ValidTo": ValidTo, "Activated": Activated, "ID_Application": ID_Application, "Code": Code, "UserName": UserName, "Password": Password, "NickName": NickName, "FirstName": FirstName, "LastName": LastName, "ID_Sex": ID_Sex, "Email": Email, "IP": IP, "FirstNameParent": FirstNameParent, "LastNameParent": LastNameParent, "EmailParent": EmailParent})

    # Znovu odeslat aktivační email
    def UserActivationUpdateResend(self, ID_Login, ID, Birthday, ValidTo, Activated, ID_Application, Code=None, UserName=None, Password=None, NickName=None, FirstName=None, LastName=None, ID_Sex=None, Email=None, IP=None, FirstNameParent=None, LastNameParent=None, EmailParent=None):
        return self._client.service.UserActivationUpdateResend({"ID_Login": ID_Login, "ID": ID, "Birthday": Birthday, "ValidTo": ValidTo, "Activated": Activated, "ID_Application": ID_Application, "Code": Code, "UserName": UserName, "Password": Password, "NickName": NickName, "FirstName": FirstName, "LastName": LastName, "ID_Sex": ID_Sex, "Email": Email, "IP": IP, "FirstNameParent": FirstNameParent, "LastNameParent": LastNameParent, "EmailParent": EmailParent})

    # Upravit aktivaci účtu
    def UserActivationUpdate(self, ID_Login, ID, Birthday, ValidTo, Activated, ID_Application, Code=None, UserName=None, Password=None, NickName=None, FirstName=None, LastName=None, ID_Sex=None, Email=None, IP=None, FirstNameParent=None, LastNameParent=None, EmailParent=None):
        return self._client.service.UserActivationUpdate({"ID_Login": ID_Login, "ID": ID, "Birthday": Birthday, "ValidTo": ValidTo, "Activated": Activated, "ID_Application": ID_Application, "Code": Code, "UserName": UserName, "Password": Password, "NickName": NickName, "FirstName": FirstName, "LastName": LastName, "ID_Sex": ID_Sex, "Email": Email, "IP": IP, "FirstNameParent": FirstNameParent, "LastNameParent": LastNameParent, "EmailParent": EmailParent})

    # Načíst ověření uživatele
    def UserAuthenticationAll(self, ID_Login, ID_User):
        return self._client.service.UserAuthenticationAll({"ID_Login": ID_Login, "ID_User": ID_User})

    # Načíst detail ověření
    def UserAuthenticationDetail(self, ID_Login, ID):
        return self._client.service.UserAuthenticationDetail({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail ověření
    def UserAuthenticationDetailForm(self, ID_Login, ID_User):
        return self._client.service.UserAuthenticationDetailForm({"ID_Login": ID_Login, "ID_User": ID_User})

    # Založit ověření
    def UserAuthenticationInsert(self, ID_Login, ID_Person, ID_User, Number=None, Code=None, NumberDataBox=None):
        return self._client.service.UserAuthenticationInsert({"ID_Login": ID_Login, "ID_Person": ID_Person, "ID_User": ID_User, "Number": Number, "Code": Code, "NumberDataBox": NumberDataBox})

    # No documentation
    def UserAuthenticationStateAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.UserAuthenticationStateAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # No documentation
    def UserAuthenticationTypeAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.UserAuthenticationTypeAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Založit ověření uživatele
    def UserAuthenticationRequest(self, ID_Login, ID_Person, ID_User):
        return self._client.service.UserAuthenticationRequest({"ID_Login": ID_Login, "ID_Person": ID_Person, "ID_User": ID_User})

    # Nahrát ověřený formulář
    def UserAuthenticationUpdateForm(self, ID_Login, ID, ID_User, DateCreate, ID_UserAuthenticated, DateAuthenticated, ID_UserAuthenticationType=None, UserAuthenticationType=None, ID_UserAuthenticationState=None, UserAuthenticationState=None, Code=None, Number=None, Content=None, FormExtension=None, FormContent=None):
        return self._client.service.UserAuthenticationUpdateForm({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "DateCreate": DateCreate, "ID_UserAuthenticated": ID_UserAuthenticated, "DateAuthenticated": DateAuthenticated, "ID_UserAuthenticationType": ID_UserAuthenticationType, "UserAuthenticationType": UserAuthenticationType, "ID_UserAuthenticationState": ID_UserAuthenticationState, "UserAuthenticationState": UserAuthenticationState, "Code": Code, "Number": Number, "Content": Content, "FormExtension": FormExtension, "FormContent": FormContent})

    # Načtení externích informací o uživateli
    def UserDetailExternal(self, ID_Login, ID, ID_Person):
        return self._client.service.UserDetailExternal({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person})

    # Načtení informací o uživateli pro dvoufaktorové přihlášení
    def UserDetailTwoFactor(self, ID_Login, ID):
        return self._client.service.UserDetailTwoFactor({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam záložních kódů uživatele
    def UserLoginCodeAll(self, ID_Login, ID_User, ID):
        return self._client.service.UserLoginCodeAll({"ID_Login": ID_Login, "ID_User": ID_User, "ID": ID})

    # Zkontrolovat platnost tokenu
    def UserLoginCodeOtherVerify(self, ID_Login, ID_User, Token=None, Type=None):
        return self._client.service.UserLoginCodeOtherVerify({"ID_Login": ID_Login, "ID_User": ID_User, "Token": Token, "Type": Type})

    # Vygenerovat kód pro přihlášení přes 2F
    def UserLoginCodeOtherGenerateEmailCode(self, ID_Login, ID, ID_User, Created, Used, IsValid, IsActive, Code=None):
        return self._client.service.UserLoginCodeOtherGenerateEmailCode({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "Created": Created, "Used": Used, "IsValid": IsValid, "IsActive": IsActive, "Code": Code})

    # Vygenerovat záložní kódy pro uživatele
    def UserLoginCodeOtherGenerate(self, ID_Login, ID, ID_User, Created, Used, IsValid, IsActive, Code=None):
        return self._client.service.UserLoginCodeOtherGenerate({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "Created": Created, "Used": Used, "IsValid": IsValid, "IsActive": IsActive, "Code": Code})

    # Načíst seznam zařízení použitých přihlášení
    def UserLoginDeviceAll(self, ID_Login, ID, ID_User):
        return self._client.service.UserLoginDeviceAll({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User})

    # Smazat všechna zařízení použité k přihlášení
    def UserLoginDeviceDeleteAll(self, ID_Login, ID_User):
        return self._client.service.UserLoginDeviceDeleteAll({"ID_Login": ID_Login, "ID_User": ID_User})

    # Smazat zařízení použité k přihlášení
    def UserLoginDeviceDelete(self, ID_Login, ID):
        return self._client.service.UserLoginDeviceDelete({"ID_Login": ID_Login, "ID": ID})

    # Upravit zařízení použité k přihlášení
    def UserLoginDeviceUpdate(self, ID_Login, ID, Created, ValidTo, ID_User, IsValid, IsMobile, Token=None, Browser=None, System=None, UserAgent=None, DisplayName=None):
        return self._client.service.UserLoginDeviceUpdate({"ID_Login": ID_Login, "ID": ID, "Created": Created, "ValidTo": ValidTo, "ID_User": ID_User, "IsValid": IsValid, "IsMobile": IsMobile, "Token": Token, "Browser": Browser, "System": System, "UserAgent": UserAgent, "DisplayName": DisplayName})

    # Reset barevného nastavení uživatele
    def UserRoleUpdateColorReset(self, ID_Login, ID, ID_User, ID_Role, ID_Group, Color=None):
        return self._client.service.UserRoleUpdateColorReset({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Role": ID_Role, "ID_Group": ID_Group, "Color": Color})

    # Upravit barvu role uživatele
    def UserRoleUpdateColor(self, ID_Login, ID, ID_User, ID_Role, ID_Group, Color=None):
        return self._client.service.UserRoleUpdateColor({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Role": ID_Role, "ID_Group": ID_Group, "Color": Color})

    # Upravit výchozí řazení rolí uživatele
    def UserRoleUpdateRestoreOrder(self, ID_Login, ID_User):
        return self._client.service.UserRoleUpdateRestoreOrder({"ID_Login": ID_Login, "ID_User": ID_User})

    # Změnit viditelnost role
    def UserRoleUpdateIsActive(self, ID_Login, ID, ID_User, ID_Role, ID_Group, Color=None):
        return self._client.service.UserRoleUpdateIsActive({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Role": ID_Role, "ID_Group": ID_Group, "Color": Color})

    # Upravit nastavení 2F uživatele
    def UserUpdateTwoFactorDate(self, ID_Login, ID):
        return self._client.service.UserUpdateTwoFactorDate({"ID_Login": ID_Login, "ID": ID})

    # Upravit nastavení 2F uživatele
    def UserUpdateTwoFactor(self, ID_Login, ID, IsEnabledTwoFactor, ID_TwoFactorType=None):
        return self._client.service.UserUpdateTwoFactor({"ID_Login": ID_Login, "ID": ID, "IsEnabledTwoFactor": IsEnabledTwoFactor, "ID_TwoFactorType": ID_TwoFactorType})

    # Úprava počtu zobrazovaných oblíbených položek
    def UserUpdateFavoriteLimit(self, ID_Login, FavoriteLimit):
        return self._client.service.UserUpdateFavoriteLimit({"ID_Login": ID_Login, "FavoriteLimit": FavoriteLimit})

    # Změnit heslo administrátorem
    def UserUpdatePasswordAdmin(self, ID_Login, ID, Password=None, Password2=None):
        return self._client.service.UserUpdatePasswordAdmin({"ID_Login": ID_Login, "ID": ID, "Password": Password, "Password2": Password2})

    # Načíst seznam sazeb DPH
    def VatRateAll(self, ID_Login, ID, DisplayName=None):
        return self._client.service.VatRateAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Načíst detail sazby DPH podle typu sazby DPH
    def VatRateDetailVatRateType(self, ID_Login, ID_VatRateType=None):
        return self._client.service.VatRateDetailVatRateType({"ID_Login": ID_Login, "ID_VatRateType": ID_VatRateType})

    # Načíst detail sazby DPH
    def VatRateDetailPrice(self, ID_Login, ID, Price):
        return self._client.service.VatRateDetailPrice({"ID_Login": ID_Login, "ID": ID, "Price": Price})

    # Načíst detail sazby DPH
    def VatRateDetail(self, ID_Login, ID):
        return self._client.service.VatRateDetail({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam akcí
    def ActionAll(self, ID_Login, DisplayName=None, ID_Table=None, ID_TableRelated=None, ID_Operation=None):
        return self._client.service.ActionAll({"ID_Login": ID_Login, "DisplayName": DisplayName, "ID_Table": ID_Table, "ID_TableRelated": ID_TableRelated, "ID_Operation": ID_Operation})

    # Načíst seznam chyb
    def ErrorAll(self, ID_Login, ID_User, DateFrom, DateTo, IsProcessed, DisplayName=None, ID_ErrorType=None, IgnoredErrorType=None):
        return self._client.service.ErrorAll({"ID_Login": ID_Login, "ID_User": ID_User, "DateFrom": DateFrom, "DateTo": DateTo, "IsProcessed": IsProcessed, "DisplayName": DisplayName, "ID_ErrorType": ID_ErrorType, "IgnoredErrorType": IgnoredErrorType})

    # Načíst detail chyby
    def ErrorDetail(self, ID_Login, ID):
        return self._client.service.ErrorDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit chybu
    def ErrorInsert(self, ID_Login, ID, ID_User, ID_Person, Date, IsProcessed, DisplayName=None, Person=None, ID_ErrorType=None, ErrorType=None, URL=None, Description=None, Browser=None, IP=None):
        return self._client.service.ErrorInsert({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Person": ID_Person, "Date": Date, "IsProcessed": IsProcessed, "DisplayName": DisplayName, "Person": Person, "ID_ErrorType": ID_ErrorType, "ErrorType": ErrorType, "URL": URL, "Description": Description, "Browser": Browser, "IP": IP})

    # Upravit chybu
    def ErrorUpdate(self, ID_Login, ID, ID_User, ID_Person, Date, IsProcessed, DisplayName=None, Person=None, ID_ErrorType=None, ErrorType=None, URL=None, Description=None, Browser=None, IP=None):
        return self._client.service.ErrorUpdate({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Person": ID_Person, "Date": Date, "IsProcessed": IsProcessed, "DisplayName": DisplayName, "Person": Person, "ID_ErrorType": ID_ErrorType, "ErrorType": ErrorType, "URL": URL, "Description": Description, "Browser": Browser, "IP": IP})

    # Načíst seznam typů skupin
    def GroupTypeAll(self, ID_Login, CanLogin, DisplayName=None, ID_Table=None):
        return self._client.service.GroupTypeAll({"ID_Login": ID_Login, "CanLogin": CanLogin, "DisplayName": DisplayName, "ID_Table": ID_Table})

    # Načíst seznam položek logu
    def LogAll(self, ID_Login, DisplayObjectId, ID_User, ID_TableDisplay=None, ID_Operation=None):
        return self._client.service.LogAll({"ID_Login": ID_Login, "DisplayObjectId": DisplayObjectId, "ID_User": ID_User, "ID_TableDisplay": ID_TableDisplay, "ID_Operation": ID_Operation})

    # Načíst detail logu
    def LogDetail(self, ID_Login, ID):
        return self._client.service.LogDetail({"ID_Login": ID_Login, "ID": ID})

    # Načíst změněné vlastnosti
    def LogDetailHistory(self, ID_Login, ID):
        return self._client.service.LogDetailHistory({"ID_Login": ID_Login, "ID": ID})

    # Prodloužení platnosti přihlašovacího tokenu o 30 minut
    def LoginUpdateRefresh(self, ID):
        return self._client.service.LoginUpdateRefresh({"ID": ID})

    # Odhlášení uživatele
    def LoginUpdateLogout(self, ID):
        return self._client.service.LoginUpdateLogout({"ID": ID})

    # Načíst seznam skupin
    def GroupAll(self, ID_Login, ID, DisplayName=None):
        return self._client.service.GroupAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Přihlášení uživatele na jinou roli
    def LoginUpdate(self, ID, ID_UserRole):
        return self._client.service.LoginUpdate({"ID": ID, "ID_UserRole": ID_UserRole})

    # Načíst seznam operací
    def OperationAll(self, ID_Login, DisplayName=None):
        return self._client.service.OperationAll({"ID_Login": ID_Login, "DisplayName": DisplayName})

    # Načíst seznam oprávnění
    def PermissionAll(self, ID_Login, IsStatic, ID_Role, ID=None, DisplayName=None, ID_GroupType=None):
        return self._client.service.PermissionAll({"ID_Login": ID_Login, "IsStatic": IsStatic, "ID_Role": ID_Role, "ID": ID, "DisplayName": DisplayName, "ID_GroupType": ID_GroupType})

    # Vrátí seznam akcí, které může přihlášený uživatele vyvolat pro zadaný záznam
    def ActionVerify(self, ID_Login, ID, IsRaiseError, ID_Table=None, ID_Action=None):
        return self._client.service.ActionVerify({"ID_Login": ID_Login, "ID": ID, "IsRaiseError": IsRaiseError, "ID_Table": ID_Table, "ID_Action": ID_Action})

    # Vrátí seznam oprávnění přhlášeného uživatele
    def PermissionAllLogin(self, ID_Login, ID=None):
        return self._client.service.PermissionAllLogin({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam rolí
    def RoleAll(self, ID_Login, DisplayName=None, ID_UnitType=None, ID_GroupType=None):
        return self._client.service.RoleAll({"ID_Login": ID_Login, "DisplayName": DisplayName, "ID_UnitType": ID_UnitType, "ID_GroupType": ID_GroupType})

    # Smazat roli
    def RoleDelete(self, ID_Login, ID, IsHidden, IsTwoFactorRequired, DisplayName=None, ID_GroupType=None, GroupType=None, ID_UnitType=None, UnitType=None, Color=None):
        return self._client.service.RoleDelete({"ID_Login": ID_Login, "ID": ID, "IsHidden": IsHidden, "IsTwoFactorRequired": IsTwoFactorRequired, "DisplayName": DisplayName, "ID_GroupType": ID_GroupType, "GroupType": GroupType, "ID_UnitType": ID_UnitType, "UnitType": UnitType, "Color": Color})

    # Načíst detail role
    def RoleDetail(self, ID_Login, ID):
        return self._client.service.RoleDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit roli
    def RoleInsert(self, ID_Login, ID, IsHidden, IsTwoFactorRequired, DisplayName=None, ID_GroupType=None, GroupType=None, ID_UnitType=None, UnitType=None, Color=None):
        return self._client.service.RoleInsert({"ID_Login": ID_Login, "ID": ID, "IsHidden": IsHidden, "IsTwoFactorRequired": IsTwoFactorRequired, "DisplayName": DisplayName, "ID_GroupType": ID_GroupType, "GroupType": GroupType, "ID_UnitType": ID_UnitType, "UnitType": UnitType, "Color": Color})

    # Načíst seznam práv přiřazených do role
    def RolePermissionAll(self, ID_Login, ID_Role, ID_Permission=None):
        return self._client.service.RolePermissionAll({"ID_Login": ID_Login, "ID_Role": ID_Role, "ID_Permission": ID_Permission})

    # Odebrat právo z role
    def RolePermissionDelete(self, ID_Login, ID, ID_Role, IsHierarchic, ID_Permission=None):
        return self._client.service.RolePermissionDelete({"ID_Login": ID_Login, "ID": ID, "ID_Role": ID_Role, "IsHierarchic": IsHierarchic, "ID_Permission": ID_Permission})

    # Přidat právo do role
    def RolePermissionInsert(self, ID_Login, ID, ID_Role, IsHierarchic, ID_Permission=None):
        return self._client.service.RolePermissionInsert({"ID_Login": ID_Login, "ID": ID, "ID_Role": ID_Role, "IsHierarchic": IsHierarchic, "ID_Permission": ID_Permission})

    # Upravit přiřazení práva do role
    def RolePermissionUpdate(self, ID_Login, ID, ID_Role, IsHierarchic, ID_Permission=None):
        return self._client.service.RolePermissionUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Role": ID_Role, "IsHierarchic": IsHierarchic, "ID_Permission": ID_Permission})

    # Upravit roli
    def RoleUpdate(self, ID_Login, ID, IsHidden, IsTwoFactorRequired, DisplayName=None, ID_GroupType=None, GroupType=None, ID_UnitType=None, UnitType=None, Color=None):
        return self._client.service.RoleUpdate({"ID_Login": ID_Login, "ID": ID, "IsHidden": IsHidden, "IsTwoFactorRequired": IsTwoFactorRequired, "DisplayName": DisplayName, "ID_GroupType": ID_GroupType, "GroupType": GroupType, "ID_UnitType": ID_UnitType, "UnitType": UnitType, "Color": Color})

    # Načíst seznam uživatelů
    def UserAll(self, ID_Login, ID, ID_Person, ID_Unit, UserName=None, DisplayName=None):
        return self._client.service.UserAll({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "ID_Unit": ID_Unit, "UserName": UserName, "DisplayName": DisplayName})

    # Načíst seznam rolí přiřazených uživateli
    def UserRoleAll(self, ID_Login, ID_User, ID_Role, IsActive, CanEdit, ID, ID_GroupType=None):
        return self._client.service.UserRoleAll({"ID_Login": ID_Login, "ID_User": ID_User, "ID_Role": ID_Role, "IsActive": IsActive, "CanEdit": CanEdit, "ID": ID, "ID_GroupType": ID_GroupType})

    # Načíst seznam obsazení rolí v jednotce
    def UserRoleALLUnit(self, ID_Login, ID_Unit, ID_Role):
        return self._client.service.UserRoleALLUnit({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "ID_Role": ID_Role})

    # Odebrat uživateli roli
    def UserRoleDelete(self, ID_Login, ID):
        return self._client.service.UserRoleDelete({"ID_Login": ID_Login, "ID": ID})

    # Přidat uživateli roli
    def UserRoleInsert(self, ID_Login, ID, ID_User, ID_Role, ID_Group, Color=None):
        return self._client.service.UserRoleInsert({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Role": ID_Role, "ID_Group": ID_Group, "Color": Color})

    # Upravit roli uživatele
    def UserRoleUpdate(self, ID_Login, ID, ID_User, ID_Role, ID_Group, Color=None):
        return self._client.service.UserRoleUpdate({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Role": ID_Role, "ID_Group": ID_Group, "Color": Color})

    # Upravit uživatele
    def UserUpdate(self, ID_Login, ID, IsEnabled, Password=None, PasswordActual=None):
        return self._client.service.UserUpdate({"ID_Login": ID_Login, "ID": ID, "IsEnabled": IsEnabled, "Password": Password, "PasswordActual": PasswordActual})

    # Načíst seznam dnů v týdnu
    def WeekDayAll(self, ID_Login, DisplayName=None):
        return self._client.service.WeekDayAll({"ID_Login": ID_Login, "DisplayName": DisplayName})

    # Přihlášení uživatele
    def LoginInsert(self, ID_UserRole, ID_Application, IsPersistent, ID_PersistentLogin, IsMobile, UserName=None, Password=None, IP=None, Token=None, UserAgent=None, Place=None):
        return self._client.service.LoginInsert({"ID_UserRole": ID_UserRole, "ID_Application": ID_Application, "IsPersistent": IsPersistent, "ID_PersistentLogin": ID_PersistentLogin, "IsMobile": IsMobile, "UserName": UserName, "Password": Password, "IP": IP, "Token": Token, "UserAgent": UserAgent, "Place": Place})

    # Načtení informací o uživateli
    def UserDetail(self, ID_Login, ID):
        return self._client.service.UserDetail({"ID_Login": ID_Login, "ID": ID})

    # Registrace uživatele
    def UserInsert(self, Birthday, UserName=None, Password=None, FirstName=None, LastName=None, NickName=None, Email=None, ID_Sex=None):
        return self._client.service.UserInsert({"Birthday": Birthday, "UserName": UserName, "Password": Password, "FirstName": FirstName, "LastName": LastName, "NickName": NickName, "Email": Email, "ID_Sex": ID_Sex})

    # Žádost o zaslání e-mailu při ztrátě hesla
    def UserPasswordRequest(self, UserName=None, Email=None):
        return self._client.service.UserPasswordRequest({"UserName": UserName, "Email": Email})

    # Změna zapomenutého hesla pomocí jedinečného identifikátoru
    def UserUpdatePassword(self, PasswordRequest, Password=None):
        return self._client.service.UserUpdatePassword({"PasswordRequest": PasswordRequest, "Password": Password})




# -*- coding: utf-8 -*-

import zeep

# Generovaní tiskových sestav
class Reports(object):
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/Reports.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/Reports.asmx?wsdl')

    # Tisková sestava: Přehled účastníků tábora
    def ParticipantCampExcel(self, ID_Login, ID_EventCamp):
        return self._client.service.ParticipantCampExcel({"ID_Login": ID_Login, "ID_EventCamp": ID_EventCamp})

    # Tisková sestava: Přehled žádostí o dotaci pro OJ
    def GrantHeadquartersUniversal(self, ID_Login, Year, Format, ID_GrantState=None):
        return self._client.service.GrantHeadquartersUniversal({"ID_Login": ID_Login, "Year": Year, "Format": Format, "ID_GrantState": ID_GrantState})

    # Tisková sestava: Přehled účastníků vzdělávací akce
    def ParticipantEducationFeeExcel(self, ID_Login, ID_EventEducation, ID_EventEducationCourse, IsActive):
        return self._client.service.ParticipantEducationFeeExcel({"ID_Login": ID_Login, "ID_EventEducation": ID_EventEducation, "ID_EventEducationCourse": ID_EventEducationCourse, "IsActive": IsActive})

    # Tisková sestava: Registrované osoby
    def UnitRegistrationPersons(self, ID_Login, ID, FileFormat, IncludeChild):
        return self._client.service.UnitRegistrationPersons({"ID_Login": ID_Login, "ID": ID, "FileFormat": FileFormat, "IncludeChild": IncludeChild})

    # Tisková sestava: Ručně generované dekrety
    def EventEducationLetterIssueAllZIP(self, ID_Login, ID_Items=None):
        return self._client.service.EventEducationLetterIssueAllZIP({"ID_Login": ID_Login, "ID_Items": ID_Items})

    # Tisková sestava: Ručně generované dekrety a absolventské listy
    def EventEducationLetterIssueAll(self, ID_Login, ID_Items=None):
        return self._client.service.EventEducationLetterIssueAll({"ID_Login": ID_Login, "ID_Items": ID_Items})

    # Tisková sestava: Přehled plateb záloh žádostí o dotace
    def GrantAdvancePaymentList(self, ID_Login, Year, DaysAhead, ID_GrantType=None, ID_State=None):
        return self._client.service.GrantAdvancePaymentList({"ID_Login": ID_Login, "Year": Year, "DaysAhead": DaysAhead, "ID_GrantType": ID_GrantType, "ID_State": ID_State})

    # Tisková sestava: Přehled žádostí o dotaci pro OJ
    def GrantHeadquartersUnorganizedYouth(self, ID_Login, Year, Format, ID_GrantState=None):
        return self._client.service.GrantHeadquartersUnorganizedYouth({"ID_Login": ID_Login, "Year": Year, "Format": Format, "ID_GrantState": ID_GrantState})

    # Tisková sestava: Přehled žádostí o dotaci pro OJ
    def GrantHeadquartersBuilding(self, ID_Login, Year, Format, ID_GrantState=None):
        return self._client.service.GrantHeadquartersBuilding({"ID_Login": ID_Login, "Year": Year, "Format": Format, "ID_GrantState": ID_GrantState})

    # Tisková sestava: Hospodářský výkaz
    def StatementDetail(self, ID_Login, ID, ShowOverview, FileFormat=None):
        return self._client.service.StatementDetail({"ID_Login": ID_Login, "ID": ID, "ShowOverview": ShowOverview, "FileFormat": FileFormat})

    # Tisková sestava: Dekrety a absolventské listy
    def EventEducationLetterAllWithAttachmenZIP(self, ID_Login, IsParticipantEducation, ID_Items=None):
        return self._client.service.EventEducationLetterAllWithAttachmenZIP({"ID_Login": ID_Login, "IsParticipantEducation": IsParticipantEducation, "ID_Items": ID_Items})

    # Tisková sestava: Příloha k vůdcovskému dekretu
    def EventEducationLetterAllAttachment(self, ID_Login, IsParticipantEducation, ExportAttachments, ID_Items=None):
        return self._client.service.EventEducationLetterAllAttachment({"ID_Login": ID_Login, "IsParticipantEducation": IsParticipantEducation, "ExportAttachments": ExportAttachments, "ID_Items": ID_Items})

    # Tisková sestava: Dekrety a absolventské listy
    def EventEducationLetterAll(self, ID_Login, IsParticipantEducation, ID_Items=None):
        return self._client.service.EventEducationLetterAll({"ID_Login": ID_Login, "IsParticipantEducation": IsParticipantEducation, "ID_Items": ID_Items})

    # Tisková sestava: Šablona souhlasu kandidáta sněmu se zápisem do spolkového rejstříku
    def CandidateFunctionAgreementDetail(self, ID_Login, ID):
        return self._client.service.CandidateFunctionAgreementDetail({"ID_Login": ID_Login, "ID": ID})

    # Tisková sestava: Šablona souhlasu se zápisem do spolkového rejstříku
    def FunctionAgreementDetail(self, ID_Login, ID):
        return self._client.service.FunctionAgreementDetail({"ID_Login": ID_Login, "ID": ID})

    # Tisková sestava: Přehled dotovaných vzdělávacích akcí
    def GrantOverview(self, ID_Login, Year, Person=None):
        return self._client.service.GrantOverview({"ID_Login": ID_Login, "Year": Year, "Person": Person})

    # Tisková sestava: Přehled žádostí o dotaci pro OJ
    def GrantHeadquarters(self, ID_Login, Year, Format, ID_GrantType=None):
        return self._client.service.GrantHeadquarters({"ID_Login": ID_Login, "Year": Year, "Format": Format, "ID_GrantType": ID_GrantType})

    # Přehled nových kvalifikací
    def QualificationAllNewSummary(self, ID_Login, From, To, ID_QualificationTypeList=None):
        return self._client.service.QualificationAllNewSummary({"ID_Login": ID_Login, "From": From, "To": To, "ID_QualificationTypeList": ID_QualificationTypeList})

    # Tisková sestava: Přehled žádostí o dotaci pro OJ
    def GrantUnitSummary(self, ID_Login, ID_Unit, Year, Format):
        return self._client.service.GrantUnitSummary({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "Year": Year, "Format": Format})

    # Tisková sestava: Přehled účastníků vzdělávací akce
    def ParticipantEducationExcel(self, ID_Login, ID_EventEducation, ID_EventEducationCourse, IsActive):
        return self._client.service.ParticipantEducationExcel({"ID_Login": ID_Login, "ID_EventEducation": ID_EventEducation, "ID_EventEducationCourse": ID_EventEducationCourse, "IsActive": IsActive})

    # Tisková sestava: Vzdělávací akce export
    def EventEducationExportExcel(self, ID_Login, ID, ID_EventEducationType, FileFormat, ID_EventEducationGroup=None, DisplayNameFilter=None):
        return self._client.service.EventEducationExportExcel({"ID_Login": ID_Login, "ID": ID, "ID_EventEducationType": ID_EventEducationType, "FileFormat": FileFormat, "ID_EventEducationGroup": ID_EventEducationGroup, "DisplayNameFilter": DisplayNameFilter})

    # Tisková sestava: Vzdělávací akce export
    def EventEducationExport(self, ID_Login, ID, ID_EventEducationType, FileFormat, ID_EventEducationGroup=None, DisplayNameFilter=None):
        return self._client.service.EventEducationExport({"ID_Login": ID_Login, "ID": ID, "ID_EventEducationType": ID_EventEducationType, "FileFormat": FileFormat, "ID_EventEducationGroup": ID_EventEducationGroup, "DisplayNameFilter": DisplayNameFilter})

    # Tisková sestava: Členská karty
    def MemberCardDetail(self, ID_Login, ID, ID_Person, Birthday, Year, DateCreate, Price, IsAuthorized, IsPaid, ValidFrom, ValidTo, ID_PersonSchool, ID_PersonRegistration, ID_DocumentMediumPhoto, ID_MemberCardState=None, MemberCardState=None, DisplayName=None, Person=None, ID_MemberCardType=None, MemberCardType=None, PersonSchool=None, PersonSchoolCity=None, UnitStredisko=None, LeaderContact=None, StorageMediumPhoto=None):
        return self._client.service.MemberCardDetail({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "Birthday": Birthday, "Year": Year, "DateCreate": DateCreate, "Price": Price, "IsAuthorized": IsAuthorized, "IsPaid": IsPaid, "ValidFrom": ValidFrom, "ValidTo": ValidTo, "ID_PersonSchool": ID_PersonSchool, "ID_PersonRegistration": ID_PersonRegistration, "ID_DocumentMediumPhoto": ID_DocumentMediumPhoto, "ID_MemberCardState": ID_MemberCardState, "MemberCardState": MemberCardState, "DisplayName": DisplayName, "Person": Person, "ID_MemberCardType": ID_MemberCardType, "MemberCardType": MemberCardType, "PersonSchool": PersonSchool, "PersonSchoolCity": PersonSchoolCity, "UnitStredisko": UnitStredisko, "LeaderContact": LeaderContact, "StorageMediumPhoto": StorageMediumPhoto})

    # Tisková sestava: Detail 2F pro uživatele
    def UserDetailTwoFactor(self, ID_Login, ID):
        return self._client.service.UserDetailTwoFactor({"ID_Login": ID_Login, "ID": ID})

    # Tisková sestava: Kód
    def Code(self, ID_Login, ID, BarcodeHeight, ID_Table=None, ID_Column=None, BarcodeType=None, FileName=None, Text=None):
        return self._client.service.Code({"ID_Login": ID_Login, "ID": ID, "BarcodeHeight": BarcodeHeight, "ID_Table": ID_Table, "ID_Column": ID_Column, "BarcodeType": BarcodeType, "FileName": FileName, "Text": Text})

    # Tisková sestava: Likvidační protokol
    def WarehouseItemStockTakingDiscarded(self, ID_Login, ID, ID_Warehouse):
        return self._client.service.WarehouseItemStockTakingDiscarded({"ID_Login": ID_Login, "ID": ID, "ID_Warehouse": ID_Warehouse})

    # Tisková sestava: Inventurní soupis
    def WarehouseItemStockTaking(self, ID_Login, ID, ID_Warehouse):
        return self._client.service.WarehouseItemStockTaking({"ID_Login": ID_Login, "ID": ID, "ID_Warehouse": ID_Warehouse})

    # Tisková sestava: Čárový kód položky skladu
    def WarehouseItemBarcode(self, ID_Login, ID, ID_Items=None, BarcodeType=None):
        return self._client.service.WarehouseItemBarcode({"ID_Login": ID_Login, "ID": ID, "ID_Items": ID_Items, "BarcodeType": BarcodeType})

    # Tisková sestava: Hodnocení kvality
    def WarehouseItem(self, ID_Login, ID_Unit, IncludeChild, EventRent, UnitRent, CommercialRent, IsDelete, InWarehouse, Count, RowMin, Reverse, DisplayName=None, InventoryNumber=None, ID_Items=None, ID_WarehouseArray=None, ID_WarehouseTagArray=None, Sort=None, ID_WarehouseItemCategory=None, Columns=None):
        return self._client.service.WarehouseItem({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "IncludeChild": IncludeChild, "EventRent": EventRent, "UnitRent": UnitRent, "CommercialRent": CommercialRent, "IsDelete": IsDelete, "InWarehouse": InWarehouse, "Count": Count, "RowMin": RowMin, "Reverse": Reverse, "DisplayName": DisplayName, "InventoryNumber": InventoryNumber, "ID_Items": ID_Items, "ID_WarehouseArray": ID_WarehouseArray, "ID_WarehouseTagArray": ID_WarehouseTagArray, "Sort": Sort, "ID_WarehouseItemCategory": ID_WarehouseItemCategory, "Columns": Columns})

    # Tisková sestava: Srovnání výsledků kvality s ostatním
    def EvaluationCompare(self, ID_Login, ID, Culture=None):
        return self._client.service.EvaluationCompare({"ID_Login": ID_Login, "ID": ID, "Culture": Culture})

    # Tisková sestava: Grafický pohled na hodnocení podřízených jednotek
    def EvaluationShiftTable(self, ID_Login, ID, MostImportant, Format=None):
        return self._client.service.EvaluationShiftTable({"ID_Login": ID_Login, "ID": ID, "MostImportant": MostImportant, "Format": Format})

    # Tisková sestava: Přehled hlášenek pro MHMP
    def EventCampCapitalSummary(self, ID_Login, ID_Unit, IsFuture, Started, Year, IsRelation, IsChildDirect, IsChildUnit, ForEvaluation, IsKraj, DisplayName=None, ID_EventCampState=None, RegistrationNumber=None, Location=None):
        return self._client.service.EventCampCapitalSummary({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "IsFuture": IsFuture, "Started": Started, "Year": Year, "IsRelation": IsRelation, "IsChildDirect": IsChildDirect, "IsChildUnit": IsChildUnit, "ForEvaluation": ForEvaluation, "IsKraj": IsKraj, "DisplayName": DisplayName, "ID_EventCampState": ID_EventCampState, "RegistrationNumber": RegistrationNumber, "Location": Location})

    # Tisková sestava: Grafický pohled na hodnocení podřízených jednotek
    def EvaluationGraphSummary(self, ID_Login, Year, ID_EvaluationSubtype):
        return self._client.service.EvaluationGraphSummary({"ID_Login": ID_Login, "Year": Year, "ID_EvaluationSubtype": ID_EvaluationSubtype})

    # Tisková sestava: Grafický pohled na hodnocení podřízených jednotek
    def EvaluationParticipationSummary(self, ID_Login, Year):
        return self._client.service.EvaluationParticipationSummary({"ID_Login": ID_Login, "Year": Year})

    # Tisková sestava: Náhled členské karty
    def MemberCardThumbnail(self, ID_Login, ID, ID_Person, Birthday, Year, DateCreate, Price, IsAuthorized, IsPaid, ValidFrom, ValidTo, ID_PersonSchool, ID_PersonRegistration, ID_DocumentMediumPhoto, ID_MemberCardState=None, MemberCardState=None, DisplayName=None, Person=None, ID_MemberCardType=None, MemberCardType=None, PersonSchool=None, PersonSchoolCity=None, UnitStredisko=None, LeaderContact=None, StorageMediumPhoto=None):
        return self._client.service.MemberCardThumbnail({"ID_Login": ID_Login, "ID": ID, "ID_Person": ID_Person, "Birthday": Birthday, "Year": Year, "DateCreate": DateCreate, "Price": Price, "IsAuthorized": IsAuthorized, "IsPaid": IsPaid, "ValidFrom": ValidFrom, "ValidTo": ValidTo, "ID_PersonSchool": ID_PersonSchool, "ID_PersonRegistration": ID_PersonRegistration, "ID_DocumentMediumPhoto": ID_DocumentMediumPhoto, "ID_MemberCardState": ID_MemberCardState, "MemberCardState": MemberCardState, "DisplayName": DisplayName, "Person": Person, "ID_MemberCardType": ID_MemberCardType, "MemberCardType": MemberCardType, "PersonSchool": PersonSchool, "PersonSchoolCity": PersonSchoolCity, "UnitStredisko": UnitStredisko, "LeaderContact": LeaderContact, "StorageMediumPhoto": StorageMediumPhoto})

    # Tisková sestava: Výpis z registru OJ
    def RegistryMinistry(self, ID_Login):
        return self._client.service.RegistryMinistry({"ID_Login": ID_Login})

    # Tisková sestava: Hodnocení kvality
    def EvaluationDetail(self, ID_Login, ID, EvaluationPersonCount, FileFormat=None):
        return self._client.service.EvaluationDetail({"ID_Login": ID_Login, "ID": ID, "EvaluationPersonCount": EvaluationPersonCount, "FileFormat": FileFormat})

    # Tisková sestava: Přehled skutečnosti jednotlivých táborů
    def EventCampRealAll(self, ID_Login, Year):
        return self._client.service.EventCampRealAll({"ID_Login": ID_Login, "Year": Year})

    # Tisková sestava: Export osob
    def ExportPerson(self, ID_Login, ID, FileFormat=None, Units=None):
        return self._client.service.ExportPerson({"ID_Login": ID_Login, "ID": ID, "FileFormat": FileFormat, "Units": Units})

    # Tisková sestava: Přehled skutečnosti táborů
    def EventCampReal(self, ID_Login, Year):
        return self._client.service.EventCampReal({"ID_Login": ID_Login, "Year": Year})

    # Tisková sestava: Přehled hlášenek
    def EventCampSummary(self, ID_Login, ID_Unit, IsFuture, Started, Year, IsRelation, IsChildDirect, IsChildUnit, ForEvaluation, IsKraj, DisplayName=None, ID_EventCampState=None, RegistrationNumber=None, Location=None):
        return self._client.service.EventCampSummary({"ID_Login": ID_Login, "ID_Unit": ID_Unit, "IsFuture": IsFuture, "Started": Started, "Year": Year, "IsRelation": IsRelation, "IsChildDirect": IsChildDirect, "IsChildUnit": IsChildUnit, "ForEvaluation": ForEvaluation, "IsKraj": IsKraj, "DisplayName": DisplayName, "ID_EventCampState": ID_EventCampState, "RegistrationNumber": RegistrationNumber, "Location": Location})

    # Vygenerování tiskové sestavy
    def Report(self, ID_Login, ID, ReportName=None, FileFormat=None, FileName=None):
        return self._client.service.Report({"ID_Login": ID_Login, "ID": ID, "ReportName": ReportName, "FileFormat": FileFormat, "FileName": FileName})




# -*- coding: utf-8 -*-

import zeep

# Skautská energie
class Power(object):
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/Power.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/Power.asmx?wsdl')

    # Načíst seznam způsobů platby záloh
    def AdvanceTypeAll(self, ID_Login, ID_Application, ID=None, DisplayName=None):
        return self._client.service.AdvanceTypeAll({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID": ID, "DisplayName": DisplayName})

    # Načíst seznam typu ukončení smlouvy u předchozího dodavatele
    def ContractTerminationTypeAll(self, ID_Login, ID_Application, ID=None, DisplayName=None):
        return self._client.service.ContractTerminationTypeAll({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID": ID, "DisplayName": DisplayName})

    # Založit žádost energie
    def EnrollEnergyAllExport(self, ID_Login):
        return self._client.service.EnrollEnergyAllExport({"ID_Login": ID_Login})

    # Založit kandidáta o vstup do energie
    def EnrollEnergyCandidateInsert(self, ID_Login, ID_Application, Email=None, PersonalText=None):
        return self._client.service.EnrollEnergyCandidateInsert({"ID_Login": ID_Login, "ID_Application": ID_Application, "Email": Email, "PersonalText": PersonalText})

    # Procedura pro aktualizaci dokumentů
    def EnrollEnergyUpdateDocument(self, ID_Login, ID_Application, ID, ID_TempFile, ID_DocumentClass=None):
        return self._client.service.EnrollEnergyUpdateDocument({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID": ID, "ID_TempFile": ID_TempFile, "ID_DocumentClass": ID_DocumentClass})

    # Založit žádost energie z pozvánky
    def EnrollEnergyInsertAccessKey(self, ID_Login, ID_Application, AccessKey, ID, ID_Person, Birthday, ID_Unit, ID_TempfileAgreement, ID_TempFileAccount, ID_TempFileOther, OnlyValidate, AdvanceAmount, ContractTerminationDate, Note=None, ID_EnrollEnergyType=None, FirstName=None, LastName=None, IdentificationCode=None, UnitName=None, Company=None, IC=None, DIC=None, Agent=None, Function=None, Street=None, City=None, Postcode=None, EnergySupplier1=None, EnergySupplier2=None, Phone=None, Email=None, ID_AdvanceType=None, AdvanceTypeContent=None, ID_ContractTerminationType=None):
        return self._client.service.EnrollEnergyInsertAccessKey({"ID_Login": ID_Login, "ID_Application": ID_Application, "AccessKey": AccessKey, "ID": ID, "ID_Person": ID_Person, "Birthday": Birthday, "ID_Unit": ID_Unit, "ID_TempfileAgreement": ID_TempfileAgreement, "ID_TempFileAccount": ID_TempFileAccount, "ID_TempFileOther": ID_TempFileOther, "OnlyValidate": OnlyValidate, "AdvanceAmount": AdvanceAmount, "ContractTerminationDate": ContractTerminationDate, "Note": Note, "ID_EnrollEnergyType": ID_EnrollEnergyType, "FirstName": FirstName, "LastName": LastName, "IdentificationCode": IdentificationCode, "UnitName": UnitName, "Company": Company, "IC": IC, "DIC": DIC, "Agent": Agent, "Function": Function, "Street": Street, "City": City, "Postcode": Postcode, "EnergySupplier1": EnergySupplier1, "EnergySupplier2": EnergySupplier2, "Phone": Phone, "Email": Email, "ID_AdvanceType": ID_AdvanceType, "AdvanceTypeContent": AdvanceTypeContent, "ID_ContractTerminationType": ID_ContractTerminationType})

    # Načíst detail pozvánka do skautské energie
    def EnrollEnergyInvitationDetailAccessKey(self, ID_Login, ID_Application, AccessKey):
        return self._client.service.EnrollEnergyInvitationDetailAccessKey({"ID_Login": ID_Login, "ID_Application": ID_Application, "AccessKey": AccessKey})

    # Načíst detail způsobu platby záloh
    def AdvanceTypeDetail(self, ID_Login, ID_Application, ID=None):
        return self._client.service.AdvanceTypeDetail({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID": ID})

    # Naèíst soubor z pøihlášky energie
    def EnrollEnergyDownload(self, ID_Login, ID, ID_Application, Type=None):
        return self._client.service.EnrollEnergyDownload({"ID_Login": ID_Login, "ID": ID, "ID_Application": ID_Application, "Type": Type})

    # Založit pozvánku do skautské energie
    def EnrollEnergyInvitationInsert(self, ID_Login, ID, ValidTo, AccessKey, ID_Person, LastOpened, IsValid, ID_Unit, Person=None, Email=None, PersonalText=None, Unit=None, RegistrationNumber=None):
        return self._client.service.EnrollEnergyInvitationInsert({"ID_Login": ID_Login, "ID": ID, "ValidTo": ValidTo, "AccessKey": AccessKey, "ID_Person": ID_Person, "LastOpened": LastOpened, "IsValid": IsValid, "ID_Unit": ID_Unit, "Person": Person, "Email": Email, "PersonalText": PersonalText, "Unit": Unit, "RegistrationNumber": RegistrationNumber})

    # Upravit pozvánku do skautské energie
    def EnrollEnergyInvitationUpdateExpired(self, ID_Login, ID, ValidTo, AccessKey, ID_Person, LastOpened, IsValid, ID_Unit, Person=None, Email=None, PersonalText=None, Unit=None, RegistrationNumber=None):
        return self._client.service.EnrollEnergyInvitationUpdateExpired({"ID_Login": ID_Login, "ID": ID, "ValidTo": ValidTo, "AccessKey": AccessKey, "ID_Person": ID_Person, "LastOpened": LastOpened, "IsValid": IsValid, "ID_Unit": ID_Unit, "Person": Person, "Email": Email, "PersonalText": PersonalText, "Unit": Unit, "RegistrationNumber": RegistrationNumber})

    # Založit žádost energie
    def EnrollEnergyAll(self, ID_Login):
        return self._client.service.EnrollEnergyAll({"ID_Login": ID_Login})

    # Načíst dodavatele energie
    def EnergySupplierAll(self, ID_Login, ID_Application):
        return self._client.service.EnergySupplierAll({"ID_Login": ID_Login, "ID_Application": ID_Application})

    # Založit žádost energie
    def EnrollEnergyInsert(self, ID_Login, ID_Application, AccessKey, ID, ID_Person, Birthday, ID_Unit, ID_TempfileAgreement, ID_TempFileAccount, ID_TempFileOther, OnlyValidate, AdvanceAmount, ContractTerminationDate, Note=None, ID_EnrollEnergyType=None, FirstName=None, LastName=None, IdentificationCode=None, UnitName=None, Company=None, IC=None, DIC=None, Agent=None, Function=None, Street=None, City=None, Postcode=None, EnergySupplier1=None, EnergySupplier2=None, Phone=None, Email=None, ID_AdvanceType=None, AdvanceTypeContent=None, ID_ContractTerminationType=None):
        return self._client.service.EnrollEnergyInsert({"ID_Login": ID_Login, "ID_Application": ID_Application, "AccessKey": AccessKey, "ID": ID, "ID_Person": ID_Person, "Birthday": Birthday, "ID_Unit": ID_Unit, "ID_TempfileAgreement": ID_TempfileAgreement, "ID_TempFileAccount": ID_TempFileAccount, "ID_TempFileOther": ID_TempFileOther, "OnlyValidate": OnlyValidate, "AdvanceAmount": AdvanceAmount, "ContractTerminationDate": ContractTerminationDate, "Note": Note, "ID_EnrollEnergyType": ID_EnrollEnergyType, "FirstName": FirstName, "LastName": LastName, "IdentificationCode": IdentificationCode, "UnitName": UnitName, "Company": Company, "IC": IC, "DIC": DIC, "Agent": Agent, "Function": Function, "Street": Street, "City": City, "Postcode": Postcode, "EnergySupplier1": EnergySupplier1, "EnergySupplier2": EnergySupplier2, "Phone": Phone, "Email": Email, "ID_AdvanceType": ID_AdvanceType, "AdvanceTypeContent": AdvanceTypeContent, "ID_ContractTerminationType": ID_ContractTerminationType})

